#include <fstream>
#include <iostream>

#include "AneuMeshLoader.h"
#include "Exceptions.h"

void AneuMeshLoader::LoadMesh(const std::string& filename) {
    std::ifstream file(filename);
    if (!file) {
        throw FileNotFoundException();
    }
    else {
        std::cout << "SUCCESS" << std::endl;
    }

    int amount, dim;

    file >> amount >> dim;
    nodes.reserve(amount);

    for (int i = 1; i <= amount; ++i) {
        Node tmp;
        tmp.id = i;
        file >> tmp.x >> tmp.y >> tmp.z;
        tmp.ver = true;
        nodes.push_back(tmp);
    }

    file >> amount >> dim;
    finite_elements.reserve(amount);

    for (int i = 1; i <= amount; ++i) {
        FiniteElement tmp;
        tmp.elem_id = i;
        file >> tmp.material_id;
        tmp.nodes_id.reserve(dim);
        int id;

        for (int j = 0; j < dim; ++j) {
            file >> id;
            tmp.nodes_id.push_back(id);
        }

        finite_elements.push_back(std::move(tmp));
    }

    file >> amount >> dim;
    boundary_finite_elements.reserve(amount);

    for (int i = 1; i <= amount; ++i) {
        BoundaryFiniteElement tmp;
        tmp.elem_id = i;
        file >> tmp.rib_id;
        tmp.nodes_id.reserve(dim);
        int id;

        for (int j = 0; j < dim; ++j) {
            file >> id;
            tmp.nodes_id.push_back(id);
        }

        std::vector<FiniteElement> temp_elements = FiniteElementsByThreeId(tmp.nodes_id[0], tmp.nodes_id[1], tmp.nodes_id[2]);
        tmp.elem_id = temp_elements[0].elem_id;
        tmp.material_id = temp_elements[0].material_id;
        boundary_finite_elements.push_back(std::move(tmp));
    }

    file.close();
}